/***************************************************************************
	file:			emuI2C.h
	product:	API-002
	descr:		Diese API emuliert eine I2C (TWI) Schnittstelle und ermoeglicht 
						das Senden und Empfangen der Daten ueber die I2C (TWI) Schnittstelle 
						eines 8051 AT89C5131A Mikrocontrollers.
	date: 		September.2013 - first release

	version 	1.0
	compiler:	Keil Cx51 V9.05

	mc:				AT89C5131A
	crystal:	12MHz, 24MHz

	author: 	Viktor Schabelski info@approbe.de
	licence:	Creative Commons Lizenz
                http://www.stack2Learn.de/cc.html

**************************************************/

#ifndef _EMU_I2C_H
#define _EMU_I2C_H

/*-----------------------------------------------------------------------------
	includes
---------------------------------------------------*/
#include "emuI2C_config.h"



/*-----------------------------------------------------------------------------
 *	global/constant variables																									*
 *----------------------------------------------------------------------------*/
// Error Code I2C Schnittstelle
typedef enum _errorCodeEmuI2C{
	EMU_I2C_SUCCESS = 0,
	EMU_I2C_BUSY = 1,
	EMU_I2C_TRANSMISSION_FAIL = 2
}errorCodeEmuI2C_t;



/*-----------------------------------------------------------------------------
	api
---------------------------------------------------*/
// Sende Daten ueber I2C
errorCodeEmuI2C_t EmuI2C_SendData(unsigned char* pData, unsigned char size);

// Empfange Daten ueber I2C
errorCodeEmuI2C_t EmuI2C_ReceiveData(unsigned char* pData, unsigned char size);

#endif
